@@ -114,15 +114,18 @@ extern void nxagentDumpInputDevicesState(void);
  * Used in the handling of the X desktop manager protocol.
  */
 
-int nxagentXdmcpUp = 0;
-int nxagentXdmcpAlertUp = 0;
+Bool nxagentXdmcpUp = False;
+Bool nxagentXdmcpAlertUp = False;
 
 /*
  * Also used in the block, wakeup and sync handlers.
  */
 
 int nxagentBuffer;
-int nxagentBlocking;
+Bool nxagentBlocking;
+
+/* FIXME: nxagentCongestion is checked as a Boolean and as an Integer
+   (>= 4) at the same time which is weird at least */
 int nxagentCongestion;
 
 double nxagentBytesIn;
@@ -153,7 +156,7 @@ struct _DispatchRec nxagentDispatch = { UNDEFINED, 0, 0, 0 };
  * server.
  */
 
-extern int nxagentSkipImage;
+extern Bool nxagentSkipImage;
 
 void nxagentBlockHandler(void * data, struct timeval **timeout, void * mask)
 {
@@ -179,7 +182,7 @@ void nxagentBlockHandler(void * data, struct timeval **timeout, void * mask)
    * Set if we need to synchronize any drawable.
    */
 
-  static int synchronize;
+  static Bool synchronize;
 
   #ifdef BLOCKS
   fprintf(stderr, "[Begin block]\n");
@@ -199,7 +202,7 @@ void nxagentBlockHandler(void * data, struct timeval **timeout, void * mask)
 
   #endif
 
-  if (nxagentNeedConnectionChange() == 1)
+  if (nxagentNeedConnectionChange())
   {
     #ifdef TEST
     fprintf(stderr, "nxagentBlockHandler: Calling nxagentHandleConnectionChanges "
@@ -222,7 +225,7 @@ void nxagentBlockHandler(void * data, struct timeval **timeout, void * mask)
 
   #ifdef TEST
 
-  if (nxagentLastWindowDestroyed == 1)
+  if (nxagentLastWindowDestroyed)
   {
     fprintf(stderr, "nxagentBlockHandler: Elapsed time [%lu].\n",
                 now - nxagentLastWindowDestroyedTime);
@@ -302,7 +305,7 @@ void nxagentBlockHandler(void * data, struct timeval **timeout, void * mask)
    *                   are synchronized.
    */
 
-  if (synchronize == 1)
+  if (synchronize)
   {
     /*
      * We should not enter the synchronization loop if there is any
@@ -310,7 +313,7 @@ void nxagentBlockHandler(void * data, struct timeval **timeout, void * mask)
      * operation.
      */
 
-    if (nxagentForceSynchronization == 1)
+    if (nxagentForceSynchronization)
     {
       #ifdef TEST
       fprintf(stderr, "nxagentBlockHandler: Going to force a synchronization at %s.\n",
@@ -319,10 +322,10 @@ void nxagentBlockHandler(void * data, struct timeval **timeout, void * mask)
 
       nxagentSynchronizationLoop(NEVER_BREAK);
 
-      nxagentForceSynchronization = 0;
+      nxagentForceSynchronization = False;
     }
     else if (nxagentUserInput(NULL) == 0 &&
-                 nxagentBlocking == 0 &&
+                 !nxagentBlocking &&
                      nxagentCongestion <= 4)
     {
       #ifdef TEST
@@ -350,7 +353,7 @@ void nxagentBlockHandler(void * data, struct timeval **timeout, void * mask)
                            nxagentCorruptedBackgrounds > 0 ||
                                nxagentCorruptedPixmaps > 0));
 
-    if (nxagentSkipImage == 0 && synchronize == 1)
+    if (!nxagentSkipImage && synchronize)
     {
       #ifdef TEST
       fprintf(stderr, "nxagentBlockHandler: Setting a zero timeout with [%d][%d][%d] and "
@@ -391,7 +394,7 @@ void nxagentBlockHandler(void * data, struct timeval **timeout, void * mask)
 
   #ifdef DYNAMIC_DISPLAY_BUFFER
 
-  if (nxagentBlocking == 1 &&
+  if (nxagentBlocking &&
           nxagentBuffer > MINIMUM_DISPLAY_BUFFER)
   {
     nxagentBuffer >>= 1;
@@ -587,7 +590,7 @@ void nxagentWakeupHandler(void * data, int count, void * mask)
    * Can become true during the dispatch loop.
    */
 
-  nxagentBlocking = 0;
+  nxagentBlocking = False;
 
   /*
    * Check if we got new events.
@@ -648,7 +651,7 @@ void nxagentWakeupHandler(void * data, int count, void * mask)
    * the session.
    */
 
-  if (nxagentOption(Xdmcp) == 1 && nxagentXdmcpUp == 0)
+  if (nxagentOption(Xdmcp) && !nxagentXdmcpUp)
   {
     #ifdef DEBUG
     fprintf(stderr, "nxagentWakeupHandler: XdmcpState [%d].\n", XdmcpState);
@@ -656,10 +659,10 @@ void nxagentWakeupHandler(void * data, int count, void * mask)
 
     if (XdmcpState == XDM_RUN_SESSION)
     {
-      nxagentXdmcpUp = 1;
+      nxagentXdmcpUp = True;
     }
 
-    if (nxagentXdmcpUp == 0)
+    if (!nxagentXdmcpUp)
     {
       #ifdef DEBUG
       fprintf(stderr, "nxagentWakeupHandler: XdmcpTime [%lu].\n",
@@ -671,7 +674,7 @@ void nxagentWakeupHandler(void * data, int count, void * mask)
                   XdmcpTimeOutRtx);
       #endif
 
-      if (nxagentXdmcpAlertUp == 0 &&
+      if (!nxagentXdmcpAlertUp &&
               GetTimeInMillis() - XdmcpStartTime >= XDM_TIMEOUT)
       {
         #ifdef WARNING
@@ -681,7 +684,7 @@ void nxagentWakeupHandler(void * data, int count, void * mask)
 
         NXTransAlert(FAILED_XDMCP_CONNECTION_ALERT, NX_ALERT_REMOTE);
 
-        nxagentXdmcpAlertUp = 1;
+        nxagentXdmcpAlertUp = True;
       }
     }
   }
@@ -703,7 +706,7 @@ void nxagentShadowBlockHandler(void * data, struct timeval **timeout, void * mas
   fprintf(stderr, "[Begin block]\n");
   #endif
 
-  if (nxagentNeedConnectionChange() == 1)
+  if (nxagentNeedConnectionChange())
   {
     nxagentHandleConnectionChanges();
   }
@@ -732,9 +735,9 @@ void nxagentShadowBlockHandler(void * data, struct timeval **timeout, void * mas
     nxagentDispatchEvents(NULL);
   }
 
-  if (nxagentShadowResize == 1)
+  if (nxagentShadowResize)
   {
-    nxagentShadowResize = 0;
+    nxagentShadowResize = False;
 
     nxagentShadowAdaptToRatio();
   }
@@ -759,7 +762,7 @@ void nxagentShadowBlockHandler(void * data, struct timeval **timeout, void * mas
 
   nxagentShadowSendUpdates(&suspended);
 
-  if (nxagentBlocking == 0)
+  if (!nxagentBlocking)
   {
     nxagentSynchronizeDrawable((DrawablePtr) nxagentShadowPixmapPtr, DONT_WAIT,
                                    ALWAYS_BREAK, nxagentShadowWindowPtr);
@@ -830,7 +833,7 @@ void nxagentShadowWakeupHandler(void * data, int count, void * mask)
    * Can become true during the dispatch loop.
    */
 
-  nxagentBlocking = 0;
+  nxagentBlocking = False;
 
   /*
    * Check if we got new events.
@@ -1017,7 +1020,7 @@ void nxagentDispatchHandler(ClientPtr client, int in, int out)
         nxagentDispatch.in  = nxagentBytesIn;
         nxagentDispatch.out = nxagentBytesOut;
 
-        isItTimeToYield = 1;
+        isItTimeToYield = TRUE;
       }
       #ifdef DEBUG
       else
@@ -1070,7 +1073,28 @@ void nxagentDispatchHandler(ClientPtr client, int in, int out)
      * into the inner dispatch loop forever.
      */
 
-    if (!SmartScheduleSignalEnable)
+    /*
+     * The behaviour described in the comment above also happens with the
+     * smart scheduler if all of the following conditions are met:
+     * - the agent is suspended
+     * - SleepTimeMillis is set (the default is sufficient to trigger this)
+     * - a client is doing a lot of image operations
+     * - nxagentShadowCounter is 0
+     * In that case the agent will slow down the image operations by calling
+     * an intermediate sleep resulting in the client's request queue never
+     * being empty. Which in turn leads to the drain loop described above.
+     * isItTimeToYield will then never be set. The (dramatic) result of this
+     * is that nxagent will not process any signals and therefore cannot be
+     * resumed anymore!
+     * For this reason we do not limit below code to the dumb scheduler but also
+     * run it if above conditions are met - ensuring regular yields.
+     * See issue #903
+     */
+
+    if (!SmartScheduleSignalEnable ||
+	    (nxagentShadowCounter == 0 &&
+	         NXDisplayError(nxagentDisplay) == 1 &&
+	             nxagentOption(SleepTimeMillis) > 0))
     {
       if  (client -> index != nxagentDispatch.client)
       {
@@ -1105,7 +1129,7 @@ void nxagentDispatchHandler(ClientPtr client, int in, int out)
           nxagentDispatch.in  = nxagentBytesIn;
           nxagentDispatch.out = nxagentBytesOut;
 
-          isItTimeToYield = 1;
+          isItTimeToYield = TRUE;
         }
         #ifdef DEBUG
         else
@@ -1179,7 +1203,7 @@ void nxagentDispatchHandler(ClientPtr client, int in, int out)
 
         nxagentDispatchEvents(NULL);
 
-        nxagentBlocking = 1;
+        nxagentBlocking = True;
       }
 
       /*
