@@ -171,7 +171,7 @@ int nxagentSaveUnder;
  *         nxagentOpenScreen
  *   InitInput
  */
-int nxagentDoFullGeneration = 1;
+Bool nxagentDoFullGeneration = True;
 
  /*
  * True if agent is running as X2goAgent
@@ -251,7 +251,7 @@ void InitOutput(ScreenInfo *scrInfo, int argc, char *argv[])
     AddCallback(&ServerGrabCallback, nxagentGrabServerCallback, NULL);
   }
 
-  if (nxagentUserDefinedFontPath == 0)
+  if (!nxagentUserDefinedFontPath)
   {
     #ifdef TEST
     fprintf(stderr, "InitOutput: Calling nxagentVerifyDefaultFontPath.\n");
@@ -518,7 +518,7 @@ FIXME: Do we need to check the key grab if the
       fprintf(stderr, "Info: Auto-terminating session with no client running.\n");
       raise(SIGTERM);
     }
-    else if (nxagentOption(Persistent) == 0)
+    else if (!nxagentOption(Persistent))
     {
       fprintf(stderr, "Info: Auto-terminating session with persistence not allowed.\n");
       raise(SIGTERM);
@@ -610,7 +610,14 @@ void OsVendorEndRedirectErrorFFunction(void)
   nxagentEndRedirectToClientsLog();
 }
 
-ServerGrabInfoRec nxagentGrabServerInfo;
+
+/*
+ * In an uninialized nxagentGrabServerInfo .grabstate is 0 which is the
+ * value of SERVER_GRABBED. Therefore we need to initialize .grabstate
+ * with SERVER_UNGRABBED. A check in Screen.c would go wrong
+ * otherwise.
+ */
+ServerGrabInfoRec nxagentGrabServerInfo = {.grabstate = SERVER_UNGRABBED, .client = NULL};
 
 static void nxagentGrabServerCallback(CallbackListPtr *callbacks, void *data,
                                    void *args)
