@@ -161,7 +161,7 @@ XkbAgentInfoRec nxagentXkbInfo = { -1, -1, -1, -1, -1 };
  * Keyboard status, updated through XKB events.
  */
 
-XkbAgentStateRec nxagentXkbState = { 0, 0, 0, 0, 0 };
+XkbAgentStateRec nxagentXkbState = { 0, 0, 0, 0, False };
 
 /*
  * Info for disabling/enabling Xkb extension.
@@ -435,6 +435,11 @@ N/A
 
         int len = (max_keycode - min_keycode + 1) * mapWidth;
         keymap = (KeySym *)malloc(len * sizeof(KeySym));
+        if (keymap == NULL)
+        {
+          XFreeModifiermap(modifier_keymap);
+          return -1;
+        }
         for(int i = 0; i < len; ++i)
         {
           keymap[i] = keymap64[i];
@@ -776,7 +781,7 @@ XkbError:
           XkbDDXChangeControls(pDev, xkb->ctrls, xkb->ctrls);
         }
 
-        if (nxagentOption(Shadow) == 1 && pDev && pDev->key)
+        if (nxagentOption(Shadow) && pDev && pDev->key)
         {
           NXShadowInitKeymap(&(pDev->key->curKeySyms));
         }
@@ -974,7 +979,7 @@ int nxagentResetKeyboard(void)
   if (dev->key)
   {
     #ifdef XKB
-    if (noXkbExtension == 0 && dev->key->xkbInfo)
+    if (!noXkbExtension && dev->key->xkbInfo)
     {
       oldMinKeycode = dev->key->xkbInfo -> desc -> min_key_code;
       oldMaxKeycode = dev->key->xkbInfo -> desc -> max_key_code;
@@ -1132,7 +1137,7 @@ static int nxagentFreeKeyboardDeviceData(DeviceIntPtr dev)
   if (dev->key)
   {
     #ifdef XKB
-    if (noXkbExtension == 0 && dev->key->xkbInfo)
+    if (!noXkbExtension && dev->key->xkbInfo)
     {
         XkbFreeInfo(dev->key->xkbInfo);
         dev->key->xkbInfo = NULL;
@@ -1425,11 +1430,9 @@ static void nxagentXkbGetRemoteNames(void)
 
   if ((after > 0) || (type != XA_STRING) || (format != 8))
   {
-    if (data)
-    {
-      SAFE_XFree(data);
-      return;
-    }
+    /* data non-null - has been checked above */
+    SAFE_XFree(data);
+    return;
   }
 
   char *name = data;
