@@ -330,7 +330,7 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
 
         clientReady[0] = 0;
 
-        if (nxagentHaveSplashWindow() || (nxagentOption(Xdmcp) == 1 && nxagentXdmcpUp == 0))
+        if (nxagentHaveSplashWindow() || (nxagentOption(Xdmcp) && !nxagentXdmcpUp))
         {
           #ifdef TEST
           fprintf(stderr, "******Dispatch: Requesting a timeout of [%d] Ms.\n",
@@ -343,7 +343,7 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
 
         if (serverGeneration > nxagentMaxAllowedResets &&
                 nxagentSessionState == SESSION_STARTING &&
-                    (nxagentOption(Xdmcp) == 0 || nxagentXdmcpUp == 1))
+                    (!nxagentOption(Xdmcp) || nxagentXdmcpUp))
         {
           #ifdef NX_DEBUG_INPUT
           fprintf(stderr, "Session: Session started at '%s' timestamp [%u].\n",
@@ -575,13 +575,12 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
       fprintf(stderr, "Session: Session terminated at '%s'.\n", GetTimeAsString());
     }
 
-    if (nxagentOption(Shadow) == 1)
+    if (nxagentOption(Shadow))
     {
       NXShadowDestroy();
     }
     saveAgentState("TERMINATED");
 
-    nxagentFreeAtomMap();
     nxagentFreeFontData();
 #endif /* NXAGENT_SERVER */
 
