@@ -320,28 +320,25 @@ static PicturePtr createSourcePicture(void)
     if (!pPicture)
       return 0;
 
-    if (pPicture != NULL)
+    DevUnion *ppriv = (DevUnion *) (pPicture + 1);
+
+    for (int i = 0; i < picturePrivateCount; ++i)
     {
-      DevUnion *ppriv = (DevUnion *) (pPicture + 1);
+      /*
+       * Other privates are inaccessible.
+       */
 
-      for (int i = 0; i < picturePrivateCount; ++i)
-      {
-        /*
-         * Other privates are inaccessible.
-         */
-
-        ppriv[i].ptr = NULL;
-      }
-
-      char *privPictureRecAddr = (char *) &ppriv[picturePrivateCount];
-
-      ppriv[nxagentPicturePrivateIndex].ptr = (void *) privPictureRecAddr;
-
-      pPicture -> devPrivates = ppriv;
-
-      nxagentPicturePriv(pPicture) -> picture = 0;
+      ppriv[i].ptr = NULL;
     }
 
+    char *privPictureRecAddr = (char *) &ppriv[picturePrivateCount];
+
+    ppriv[nxagentPicturePrivateIndex].ptr = (void *) privPictureRecAddr;
+
+    pPicture -> devPrivates = ppriv;
+
+    nxagentPicturePriv(pPicture) -> picture = 0;
+
     pPicture->pDrawable = 0;
     pPicture->pFormat = 0;
     pPicture->pNext = 0;
@@ -531,13 +528,12 @@ void nxagentReconnectPictFormat(void *p0, XID x1, void *p2)
 }
 
 /*
- * The set of picture formats may change considerably
- * between different X servers. This poses a problem
- * while migrating NX sessions, because a requisite to
- * successfully reconnect the session is that all pic-
- * ture formats have to be available on the new X server.
- * To reduce such problems, we use a limited set of
- * pictures available on the most X servers.
+ * The set of picture formats may change considerably between
+ * different X servers. This poses a problem while migrating NX
+ * sessions, because a requisite to successfully reconnect the session
+ * is that all picture formats have to be available on the new X
+ * server.  To reduce such problems, we use a limited set of pictures
+ * available on the most X servers.
  */
 
 void nxagentPictureCreateDefaultFormats(ScreenPtr pScreen, FormatInitRec *formats, int *nformats)
