@@ -502,7 +502,8 @@ int nxagentExportProperty(WindowPtr pWin,
 
     nxagentPropWMHints propHints = {
       .flags = wmHints.flags,
-      .input = (wmHints.input == True ? 1 : 0),
+      /*.input = (wmHints.input == True ? 1 : 0), is always True*/
+      .input = 1,
       .initialState = wmHints.initial_state,
       .iconPixmap = wmHints.icon_pixmap,
       .iconWindow = wmHints.icon_window,
@@ -1244,7 +1245,7 @@ void nxagentFreePropertyList(void)
 
 /*
  * We are trying to distinguish notifications generated by an external
- * client from those genarated by our own requests.
+ * client from those generated by our own requests.
  */
 
 Bool nxagentNotifyMatchChangeProperty(void *p)
