@@ -117,10 +117,6 @@ OR PERFORMANCE OF THIS SOFTWARE.
 #include "site.h"
 #include "opaque.h"
 
-#ifdef WIN32
-#include <process.h>
-#define getpid(x) _getpid(x)
-#endif
 
 #ifdef NX_TRANS_SOCKET
 
@@ -268,9 +264,7 @@ LogInit(const char *fname, const char *backup)
 	if (saveBuffer && bufferSize > 0) {
 	    fwrite(saveBuffer, bufferPos, 1, logFile);
 	    fflush(logFile);
-#ifndef WIN32
 	    fsync(fileno(logFile));
-#endif
 	}
     }
 
@@ -398,10 +392,8 @@ LogVWrite(int verb, const char *f, va_list args)
 	    fwrite(tmpBuffer, len, 1, logFile);
 	    if (logFlush) {
 		fflush(logFile);
-#ifndef WIN32
 		if (logSync)
 		    fsync(fileno(logFile));
-#endif
 	    }
 	} else if (needBuffer) {
 	    /*
@@ -730,11 +722,9 @@ ErrorF(const char * f, ...)
 
 #ifndef NEED_STRERROR
 #ifdef SYSV
-#if !defined(ISC) || defined(ISC202) || defined(ISC22)
 #define NEED_STRERROR
 #endif
 #endif
-#endif
 
 #if defined(NEED_STRERROR) && !defined(strerror)
 extern char *sys_errlist[];
