@@ -570,8 +570,8 @@ ProcXFixesFetchRegion (ClientPtr client)
     pBox = RegionRects (pRegion);
     nBox = RegionNumRects (pRegion);
     
-    reply = malloc (sizeof (xXFixesFetchRegionReply) +
-		    nBox * sizeof (xRectangle));
+    reply = calloc (sizeof (xXFixesFetchRegionReply) +
+		    nBox * sizeof (xRectangle), 1);
     if (!reply)
 	return BadAlloc;
     reply->type = X_Reply;
