@@ -50,10 +50,6 @@ XkbInternAtom(Display *dpy,char *str,Bool only_if_exists)
     return MakeAtom(str,strlen(str),!only_if_exists);
 }
 
-#ifndef SEEK_SET
-#define	SEEK_SET 0
-#endif
-
 /***====================================================================***/
 
 static XPointer
@@ -547,10 +543,8 @@ FindTypeForKey(XkbDescPtr xkb,Atom name,unsigned width,KeySym *syms)
 	register unsigned i;
 	for (i=0;i<xkb->map->num_types;i++) {
 	    if (xkb->map->types[i].name==name) {
-#ifdef DEBUG
 		if (xkb->map->types[i].num_levels!=width)
-		    fprintf(stderr,"Group width mismatch between key and type\n");
-#endif
+		    DebugF("Group width mismatch between key and type\n");
 		return &xkb->map->types[i];
 	    }
 	}
@@ -642,7 +636,6 @@ XkbDescPtr		xkb;
 	bzero((char *)typeName,XkbNumKbdGroups*sizeof(Atom));
 	bzero((char *)type,XkbNumKbdGroups*sizeof(XkbKeyTypePtr));
 	if (wireMap.flags&XkmKeyHasTypes) {
-	    register int g;
 	    for (g=0;g<XkbNumKbdGroups;g++) {
 		if ((wireMap.flags&(1<<g))&&
 			((tmp=XkmGetCountedString(file,buf,100))>0)) {
@@ -1072,10 +1065,8 @@ unsigned i,size_toc;
     ignored_result = fread(file_info,SIZEOF(xkmFileInfo),1,file);
     size_toc= file_info->num_toc;
     if (size_toc>max_toc) {
-#ifdef DEBUG
-	fprintf(stderr,"Warning! Too many TOC entries; last %d ignored\n",
+	DebugF("Warning! Too many TOC entries; last %d ignored\n",
 							size_toc-max_toc);
-#endif
 	size_toc= max_toc;
     }
     for (i=0;i<size_toc;i++) {
@@ -1185,8 +1176,12 @@ char 		name[100];
 		return Xstrdup(name);
 	    break;
 	default:
+	  /* tmpTOC is unitilaoized here, so we use the one from toc for now.
 	    _XkbLibError(_XkbErrBadImplementation,
 				XkbConfigText(tmpTOC.type,XkbMessage),0);
+	   */
+	    _XkbLibError(_XkbErrBadImplementation,
+				XkbConfigText(toc->type,XkbMessage),0);
 	    break;
     }
     return NULL;
@@ -1215,11 +1210,7 @@ unsigned		which= need|want;
     if (result->xkb==NULL)
 	result->xkb= XkbAllocKeyboard();
     for (i=0;i<fileInfo.num_toc;i++) {
-#ifdef SEEK_SET
 	fseek(file,toc[i].offset,SEEK_SET);
-#else
-	fseek(file,toc[i].offset,0);
-#endif
 	tmp= fread(&tmpTOC,SIZEOF(xkmSectionInfo),1,file);
 	nRead= tmp*SIZEOF(xkmSectionInfo);
 	if ((tmpTOC.type!=toc[i].type)||(tmpTOC.format!=toc[i].format)||
