@@ -31,7 +31,6 @@ usage() {
 }
 
 PROJECT="nx-libs"
-NULL=""
 
 test -d ".git" || usage
 RELEASE="$1"
@@ -59,7 +58,7 @@ fi
 if ! git rev-parse --verify -q "$CHECKOUT" >/dev/null; then
     echo "   '${RELEASE}' is not a valid release number because there is no git tag named ${CHECKOUT}."
     echo "   Please specify one of the following releases:"
-    echo "HEAD (on branch `git rev-parse --abbrev-ref HEAD`)"
+    echo "HEAD (on branch $(git rev-parse --abbrev-ref HEAD))"
     git tag -l | grep "^redist" | cut -f2 -d"/" | sort -u
     exit 1
 fi
@@ -81,7 +80,7 @@ cd "${TEMP_DIR}/${PROJECT}-${RELEASE}/"
 
 # Replace symlinks by copies of the linked target files
 # Note: We don't have symlinked directories!!!
-find . -type "l" | while read link; do
+find . -type "l" | while read -r link; do
 	TARGET="$(readlink "${link}")"
 	pushd "$(dirname "${link}")" >/dev/null
 	if [ -f "${TARGET}" ]; then
@@ -156,12 +155,12 @@ if [ "x$MODE" = "xfull" ]; then
     rm -f  "nx-X11/extras/Mesa/src/mesa/main/"*.py
     rm -f  "nx-X11/extras/Mesa/src/mesa/main/"{mesa.def,Imakefile,vsnprintf.c}
 
-    find nx-X11/extras/Mesa/ -name Makefile | while read file; do rm "$file"; done
-    find nx-X11/extras/Mesa/ -name Makefile.* | while read file; do rm "$file"; done
-    find nx-X11/extras/Mesa/ -name descrip.mms | while read file; do rm "$file"; done
+    find nx-X11/extras/Mesa/ -name Makefile | while read -r file; do rm "$file"; done
+    find nx-X11/extras/Mesa/ -name 'Makefile.*' | while read -r file; do rm "$file"; done
+    find nx-X11/extras/Mesa/ -name descrip.mms | while read -r file; do rm "$file"; done
 
     # this is for 3.5.0.x only...
-    cat "debian/patches/series" | sort | grep -v '^#' | egrep "([0-9]+(_|-).*\.(full|full\+lite)\.patch)" | while read file
+    sort "debian/patches/series" | grep -v '^#' | grep -E "([0-9]+(_|-).*\.(full|full\+lite)\.patch)" | while read -r file
     do
         cp -v "debian/patches/$file" "doc/applied-patches/"
         echo "${file##*/}" >> "doc/applied-patches/series"
@@ -198,7 +197,7 @@ else
     mv LICENSE.nxcomp LICENSE
 
     # this is for 3.5.0.x only...
-    cat "debian/patches/series" | sort | grep -v '^#' | egrep "([0-9]+(_|-).*\.full\+lite\.patch)" | while read file
+    sort "debian/patches/series" | grep -v '^#' | grep -E "([0-9]+(_|-).*\.full\+lite\.patch)" | while read -r file
     do
         cp -v "debian/patches/$file" "doc/applied-patches/"
         echo "${file##*/}" >> "doc/applied-patches/series"
@@ -217,8 +216,9 @@ rm -Rf "debian/"
 rm -Rf "nx-libs.spec"
 
 # very old release did not add any README
-for f in $(ls README* 2>/dev/null); do
-    mv -v "$f" "doc/";
+for f in README*; do
+    [[ -e "$f" ]] || break # handle the case of no README* files
+    mv -v "$f" "doc/"
 done
 
 # remove files, that we do not want in the tarballs (build cruft)
